/***
 * grep.java,v 1.2 1997/12/23 17:47:22
 *
 * This is a no-frills implementation of grep using Perl regular expressions.
 * You can easily add most of the options present in most grep versions by
 * creating a MatchAction class or classes whose behavior varies based on
 * the provided flags.
 *
 * Copyright 1997 Original Reusable Objects, Inc.  All rights reserved.
 ***/

import java.io.*;
import java.util.*;

import com.oroinc.text.*;
import com.oroinc.text.regex.*;

public final class grep {
  static int _file = 0;

  // args[] is declared final so that Inner Class may reference it.
  public static final void main(final String[] args) {
    MatchActionProcessor processor = new MatchActionProcessor();

    if(args.length < 2) {
      System.err.println("Usage: grep <pattern> <filename>");
      System.exit(1);
    }

    try {
      if(args.length > 2) {
	// Print filename before line if more than one file is specified.
	// Rely on _file to point to current file being processed.
	processor.addAction(args[0], new MatchAction() {
	  public void processMatch(MatchActionInfo info) {
	    info.output.println(args[_file] + ":" + info.line);
	  }
	});
      } else {
	// We rely on the default action of printing matched 
	// lines to the given OutputStream
	processor.addAction(args[0]);
      }
    } catch(MalformedPatternException e) {
      System.err.println("Bad pattern.");
      e.printStackTrace();
      System.exit(1);
    }

    for(_file = 1; _file < args.length; _file++) {
      try {
	processor.processMatches(new FileInputStream(args[_file]), System.out);
      } catch(IOException e) {
	System.err.println("Error opening or reading " + args[_file]);
	e.printStackTrace();
	System.exit(1);
      }
    }
  }

}
